@@ -6,9 +6,10 @@ kl = sensenet.importers.import_keras_layers()
 from sensenet.constants import LEAKY_RELU_ALPHA
 
 ACTIVATORS = {
+    'leaky_relu': lambda x: tf.nn.leaky_relu(x, alpha=LEAKY_RELU_ALPHA),
+    'mish': lambda x: x * tf.math.tanh(tf.math.softplus(x)),
     'relu6': tf.nn.relu6,
-    'swish': lambda x: x * tf.sigmoid(x),
-    'leaky_relu': lambda x: tf.nn.leaky_relu(x, alpha=LEAKY_RELU_ALPHA)
+    'swish': lambda x: x * tf.sigmoid(x)
 }
 
 # The names of the trainable parameters in any layer
