@@ -10,13 +10,14 @@ from sensenet.constants import CATEGORICAL, IMAGE_PATH, BOUNDING_BOX
 from sensenet.accessors import get_image_shape
 from sensenet.load import load_points
 from sensenet.models.image import pretrained_image_model, image_feature_extractor
-from sensenet.models.image import image_layers
+from sensenet.models.image import image_layers, image_model
+from sensenet.models.image import get_pretrained_network
 from sensenet.models.settings import Settings
 from sensenet.preprocess.image import get_image_reader_fn
-from sensenet.pretrained import get_image_network
 
 EXTRA_PARAMS = {
     'image_path_prefix': 'tests/data/images/',
+    'input_image_format': 'file',
     'load_pretrained_weights': True
 }
 
@@ -29,13 +30,13 @@ def create_image_model(network_name, box_threshold, image_format):
     return pretrained_image_model(network_name, extras)
 
 def reader_for_network(network_name):
-    image_shape = get_image_shape(get_image_network(network_name))
+    image_shape = get_image_shape(get_pretrained_network(network_name))
     path_prefix = EXTRA_PARAMS['image_path_prefix']
 
     return get_image_reader_fn(image_shape, 'file', path_prefix)
 
 def classify(network_name, accuracy_threshold):
-    network = get_image_network(network_name)
+    network = get_pretrained_network(network_name)
     nlayers = len(network['image_network']['layers'])
     noutputs = network['image_network']['metadata']['outputs']
     preprocessors = network['preprocess']
@@ -93,11 +94,8 @@ def detect_bounding_boxes(network_name, nboxes, class_list, threshold):
 
     for pred in [file_pred, pixel_pred]:
         boxes, scores, classes = pred
-        assert len(boxes[0]) == nboxes
-        assert sorted(set(classes[0])) == sorted(class_list), str(set(classes[0]))
+        assert len(boxes) == len(scores) == nboxes, len(boxes)
+        assert sorted(set(classes)) == sorted(class_list), classes
 
-def test_yolov3():
-    detect_bounding_boxes('yolov3', 6, [0, 60, 53], 0.6)
-
-def test_tinyyolov3():
-    detect_bounding_boxes('tinyyolov3', 3, [0, 53], 0.4)
+def test_tinyyolov4():
+    detect_bounding_boxes('tinyyolov4', 5, [0, 53], 0.4)
